@@ -44,12 +44,12 @@ def cli():
                 if os.get_terminal_size().lines < 3
                 else Panel(
                     c,
-                    title=" ".join(
+                    title="   ".join(
                         v
                         for k, v in {
-                            "keyboard": "⌨️  Keyboard",
-                            "mouse": "🖱️  Mouse",
-                            "touchpad": "💻 Touchpad",
+                            "keyboard": " Keyboard",
+                            "mouse": "Mouse",
+                            "touchpad": "Touchpad",
                         }.items()
                         if any(k in d.name.lower() for d in args.devices)
                     ),
